Improve this Doc View Source

Extends the destination object `dst` by copying own enumerable properties from the `src` object(s) to `dst`. You can specify multiple `src` objects. If you want to preserve original objects, you can do so by passing an empty object as the target: `var object = angular.extend({}, object1, object2)`.

Note: Keep in mind that `angular.extend` does not support recursive merge (deep copy). Use `angular.merge` for this.

## Usage

`angular.extend(dst, src);`

### Arguments

Param | Type | Details
--- | --- | ---
dst | Object | Destination object.
src | Object | Source object(s).

### Returns

Object | Reference to `dst`.